@@ -56,7 +56,7 @@ int plugin_init(desc)
  struct arglist * desc;
 { 
  plug_set_id(desc, 10330);
- plug_set_version(desc, "$Revision: 1.237 $");
+ plug_set_version(desc, "$Revision: 1.238 $");
  
  plug_set_name(desc, FR_NAME, "francais");
  plug_set_name(desc, EN_NAME, NULL);
@@ -1658,9 +1658,9 @@ mark_socks_proxy(desc, port, ver)
 {
   char			str[256];
 
-  sprintf(str, "socks%d", ver);
+  snprintf(str, sizeof(str), "socks%d", ver);
   register_service(desc,port, str);
-  sprintf(str, "A SOCKS%d proxy is running on this port. ", ver);
+  snprintf(str, sizeof(str), "A SOCKS%d proxy is running on this port. ", ver);
   post_note(desc, port, str);
 }
 
@@ -1846,7 +1846,7 @@ static int plugin_do_run(desc, h, test_ssl)
 #define DIFFTV1000(t1,t2)	((t1.tv_sec - t2.tv_sec)*1000 + (t1.tv_usec - t2.tv_usec)/1000)
 
     banner_len = 0;
-    sprintf(kb, "BannerHex/%d", port);
+    snprintf(kb, sizeof(kb), "BannerHex/%d", port);
 #ifdef NEW_KB_MGMT
     bannerHex = plug_get_key(desc, kb, &type);
 #else
@@ -1880,7 +1880,7 @@ static int plugin_do_run(desc, h, test_ssl)
 
     if (banner_len == 0)
       {
-	sprintf(kb, "Banner/%d", port);
+	snprintf(kb, sizeof(kb), "Banner/%d", port);
 #ifdef NEW_KB_MGMT
 	banner = plug_get_key(desc, kb, &type);
 #else
@@ -1975,7 +1975,7 @@ static int plugin_do_run(desc, h, test_ssl)
       }
     else
       {
-	sprintf(kb, "/tmp/NoBanner/%d", port);
+	snprintf(kb, sizeof(kb), "/tmp/NoBanner/%d", port);
 	p = plug_get_key(desc, kb, &type);
 	if (p != NULL)
 	  if (type == ARG_INT)
@@ -2082,9 +2082,9 @@ select_again:
      }
 
    if (get_sent)
-     sprintf(kb, "FindService/tcp/%d/get_http", port);
+     snprintf(kb, sizeof(kb), "FindService/tcp/%d/get_http", port);
    else
-     sprintf(kb, "FindService/tcp/%d/spontaneous", port);
+     snprintf(kb, sizeof(kb), "FindService/tcp/%d/spontaneous", port);
    plug_replace_key(desc, kb, ARG_STRING, banner);
 
    {
@@ -2094,7 +2094,7 @@ select_again:
      strcat(kb, "Hex");
      for (y = 0; y < len; y ++)
        {
-	 sprintf(buf2 + 2*y, "%02x", (unsigned char) banner[y]);
+	 snprintf(buf2 + 2*y, sizeof(buf2), "%02x", (unsigned char) banner[y]);
 	 if (banner[y] == '\0') flag = 1;
        }
      buf2[2*y] = '\0';
